gchecky.model.flat_rate_shipping_t

Package gchecky :: Module model :: Class flat_rate_shipping_t |
[hide private]
[frames] | no frames]

# Class flat_rate_shipping_t

source code

       object --+
                |
        gxml.Node --+
                    |
    shipping_option_t --+
                        |
                       flat_rate_shipping_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
Inherited from `shipping_option_t`: `allowed_areas`, `excluded_areas`, `name`, `price` Inherited from `shipping_option_t` (private): `_fields`

Properties | [hide private]
Inherited from `object`: `__class__`